@@ -21,8 +21,8 @@ class TestStringIO < Test::Unit::TestCase
     # In this case, we must use eval because we need two strings literals that
     # are long enough they cannot be embedded, but also contain the same bytes.
 
-    a = eval(("x" * 1024).dump)
-    b = eval(("x" * 1024).dump)
+    a = eval("+"+("x" * 1024).dump)
+    b = eval("+"+("x" * 1024).dump)
 
     s = StringIO.new(b)
     s.getc
@@ -64,6 +64,10 @@ class TestStringIO < Test::Unit::TestCase
     assert_nil io.gets
     io.puts "abc"
     assert_nil io.string
+
+    # Null device StringIO just drop ungot string
+    io.ungetc '#'
+    assert_nil io.getc
   end
 
   def test_truncate
